# geogee


[![image](https://img.shields.io/pypi/v/geogee.svg)](https://pypi.python.org/pypi/geogee)
[![image](https://img.shields.io/conda/vn/conda-forge/geogee.svg)](https://anaconda.org/conda-forge/geogee)



[![image](https://img.shields.io/pypi/v/geogee.svg)](https://pypi.python.org/pypi/geogee)
[![image](https://static.pepy.tech/badge/geogee)](https://pepy.tech/project/geogee)
[![Conda Recipe](https://img.shields.io/badge/recipe-geogee-green.svg)](https://github.com/conda-forge/geogee-feedstock)
[![image](https://img.shields.io/conda/vn/conda-forge/geogee.svg)](https://anaconda.org/conda-forge/geogee)
[![Conda Downloads](https://img.shields.io/conda/dn/conda-forge/geogee.svg)](https://anaconda.org/conda-forge/geogee)
[![image](https://github.com/gee-community/geogee/workflows/docs/badge.svg)](https://geogee.org)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)




**A python package for geogee**


-   Free software: MIT license
-   Documentation: https://LyMot.github.io/geogee
    

## Features

-   TODO
-   TODO 2
